
/* Generated data (by glib-mkenums) */

#ifndef GOA_IDENTITY_ENUM_TYPES_H
#define GOA_IDENTITY_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "goaidentity.h" */
GType goa_identity_error_get_type (void) G_GNUC_CONST;
#define GOA_TYPE_IDENTITY_ERROR (goa_identity_error_get_type ())
GType goa_identity_sign_in_flags_get_type (void) G_GNUC_CONST;
#define GOA_TYPE_IDENTITY_SIGN_IN_FLAGS (goa_identity_sign_in_flags_get_type ())

/* enumerations from "goaidentityinquiry.h" */
GType goa_identity_query_mode_get_type (void) G_GNUC_CONST;
#define GOA_TYPE_IDENTITY_QUERY_MODE (goa_identity_query_mode_get_type ())

/* enumerations from "goaidentitymanagererror.h" */
GType goa_identity_manager_error_get_type (void) G_GNUC_CONST;
#define GOA_TYPE_IDENTITY_MANAGER_ERROR (goa_identity_manager_error_get_type ())

/* enumerations from "goakerberosidentity.h" */
GType struct_struct_get_type (void) G_GNUC_CONST;
#define STRUCT_TYPE_STRUCT (struct_struct_get_type ())

/* enumerations from "goakerberosidentityinquiry.h" */
GType goa_kerberos_identity_query_mode_get_type (void) G_GNUC_CONST;
#define GOA_TYPE_KERBEROS_IDENTITY_QUERY_MODE (goa_kerberos_identity_query_mode_get_type ())
G_END_DECLS

#endif /* GOA_IDENTITY_ENUM_TYPES_H */

/* Generated data ends here */

